# IoTAnalyzer

IoTAnalyzer is an open-source IoT device management toolkit that can help smart home owner, Internet Service Providers (ISPs), and researchers to automatically monitor smart home IoT devices, and analyze potential security and privacy vulnerabilities.

## Installation

Run the following to install:

```python
pip install iotanalyzer
```

## Usage

### Machine Learning Classifier

```python
from iotanalyzer import classifier

c = classifier
```

